impl_plugin

Macro impl_plugin 

impl_plugin!() { /* proc-macro */ }
Macro to implement the Plugin trait with handler dispatch

This generates a Plugin implementation that routes messages to handler methods based on type tags.

Example

impl_plugin! {
    MyPlugin {
        "user.create" => create_user,
        "user.delete" => delete_user,
    }
}